@@ -104,6 +104,15 @@ class FileSystemManager(object):
                 'ssd': ['discard'],
                 'compress': None,
                 'type': ['hdd', 'usb-hdd']},
+        'f2fs': {'defaultopt': defaultOpt,
+                'format': '/usr/sbin/mkfs.f2fs',
+                'formatparam': '{labelparam} -f {device}',
+                'gpt': '8300',
+                'label': '-l {labelname}',
+                'msdos': '83',
+                'ssd': [],
+                'compress': None,
+                'type': ['hdd', 'usb-hdd']},
 #        'nilfs2': {'defaultopt': defaultOpt,
 #                   'format': '/sbin/mkfs.nilfs2',
 #                   'formatparam': '{labelparam} {device}',
