@@ -273,8 +273,8 @@ class migrate(object):
     minGid = 1000
     minSysId = 1000
 
-    newUserGroups = ["audio", "cdrom", "cdrw", "games", "lp", "plugdev",
-                     "scanner" "usb", "users", "video", "wheel"]
+    newUserGroups = ["audio", "cdrom", "cdrw", "games", "lp", "lpadmin",
+                     "plugdev", "scanner" "usb", "users", "video", "wheel"]
 
     def __init__(self, prefixNewSystem):
         self.prefixNewSystem = prefixNewSystem
